@@ -34,7 +34,7 @@ class CrossEntropyLoss(Module):
         super().__init__()
         self.loss = nn.CrossEntropyLoss()
 
-    def __call__(self, outputs, targets):
+    def forward(self, outputs, targets):
         return self.loss(outputs.view(-1, outputs.shape[-1]), targets.view(-1))
 
 
@@ -108,6 +108,9 @@ class NLPAutoRegressionConfigs(TrainValidConfigs):
         ### Training or validation step
         """
 
+        # Set training/eval mode
+        self.model.train(self.mode.is_train)
+
         # Move data to the device
         data, target = batch[0].to(self.device), batch[1].to(self.device)
 
@@ -130,6 +133,8 @@ class NLPAutoRegressionConfigs(TrainValidConfigs):
         self.accuracy(output, target)
         self.accuracy.track()
 
+        self.other_metrics(output, target)
+
         # Train the model
         if self.mode.is_train:
             # Calculate gradients
